==> huaweicloudsdkhss-3.1.99-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/list_host_rasp_protect_history_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListHostRaspProtectHistoryInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_num': 'int',
        'data_list': 'list[HostRaspProtectHistoryResponseInfo]'
    }

    attribute_map = {
        'total_num': 'total_num',
        'data_list': 'data_list'
    }

    def __init__(self, total_num=None, data_list=None):
        """ListHostRaspProtectHistoryInfoResponse

        The model defined in huaweicloud sdk

        :param total_num: total number of dynamic WTPs
        :type total_num: int
        :param data_list: data list
        :type data_list: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        
        super(ListHostRaspProtectHistoryInfoResponse, self).__init__()

        self._total_num = None
        self._data_list = None
        self.discriminator = None

        if total_num is not None:
            self.total_num = total_num
        if data_list is not None:
            self.data_list = data_list

    @property
    def total_num(self):
        """Gets the total_num of this ListHostRaspProtectHistoryInfoResponse.

        total number of dynamic WTPs

        :return: The total_num of this ListHostRaspProtectHistoryInfoResponse.
        :rtype: int
        """
        return self._total_num

    @total_num.setter
    def total_num(self, total_num):
        """Sets the total_num of this ListHostRaspProtectHistoryInfoResponse.

        total number of dynamic WTPs

        :param total_num: The total_num of this ListHostRaspProtectHistoryInfoResponse.
        :type total_num: int
        """
        self._total_num = total_num

    @property
    def data_list(self):
        """Gets the data_list of this ListHostRaspProtectHistoryInfoResponse.

        data list

        :return: The data_list of this ListHostRaspProtectHistoryInfoResponse.
        :rtype: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        return self._data_list

    @data_list.setter
    def data_list(self, data_list):
        """Sets the data_list of this ListHostRaspProtectHistoryInfoResponse.

        data list

        :param data_list: The data_list of this ListHostRaspProtectHistoryInfoResponse.
        :type data_list: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        self._data_list = data_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHostRaspProtectHistoryInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkhss-3.1.146-py2.py3-none-any.whl: huaweicloudsdkhss/v5/model/list_host_rasp_protect_history_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListHostRaspProtectHistoryInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_num': 'int',
        'data_list': 'list[HostRaspProtectHistoryResponseInfo]'
    }

    attribute_map = {
        'total_num': 'total_num',
        'data_list': 'data_list'
    }

    def __init__(self, total_num=None, data_list=None):
        r"""ListHostRaspProtectHistoryInfoResponse

        The model defined in huaweicloud sdk

        :param total_num: total number of dynamic WTPs
        :type total_num: int
        :param data_list: data list
        :type data_list: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        
        super(ListHostRaspProtectHistoryInfoResponse, self).__init__()

        self._total_num = None
        self._data_list = None
        self.discriminator = None

        if total_num is not None:
            self.total_num = total_num
        if data_list is not None:
            self.data_list = data_list

    @property
    def total_num(self):
        r"""Gets the total_num of this ListHostRaspProtectHistoryInfoResponse.

        total number of dynamic WTPs

        :return: The total_num of this ListHostRaspProtectHistoryInfoResponse.
        :rtype: int
        """
        return self._total_num

    @total_num.setter
    def total_num(self, total_num):
        r"""Sets the total_num of this ListHostRaspProtectHistoryInfoResponse.

        total number of dynamic WTPs

        :param total_num: The total_num of this ListHostRaspProtectHistoryInfoResponse.
        :type total_num: int
        """
        self._total_num = total_num

    @property
    def data_list(self):
        r"""Gets the data_list of this ListHostRaspProtectHistoryInfoResponse.

        data list

        :return: The data_list of this ListHostRaspProtectHistoryInfoResponse.
        :rtype: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        return self._data_list

    @data_list.setter
    def data_list(self, data_list):
        r"""Sets the data_list of this ListHostRaspProtectHistoryInfoResponse.

        data list

        :param data_list: The data_list of this ListHostRaspProtectHistoryInfoResponse.
        :type data_list: list[:class:`huaweicloudsdkhss.v5.HostRaspProtectHistoryResponseInfo`]
        """
        self._data_list = data_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHostRaspProtectHistoryInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
